pub struct AsymmetricDecryptRequest {
pub ciphertext: Option<Vec<u8>>,
pub ciphertext_crc32c: Option<i64>,
}Expand description
Request message for KeyManagementService.AsymmetricDecrypt.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
ciphertext: Option<Vec<u8>>Required. The data encrypted with the named CryptoKeyVersion’s public key using OAEP.
ciphertext_crc32c: Option<i64>Optional. An optional CRC32C checksum of the AsymmetricDecryptRequest.ciphertext. If specified, KeyManagementService will verify the integrity of the received AsymmetricDecryptRequest.ciphertext using this checksum. KeyManagementService will report an error if the checksum verification fails. If you receive a checksum error, your client should verify that CRC32C(AsymmetricDecryptRequest.ciphertext) is equal to AsymmetricDecryptRequest.ciphertext_crc32c, and if so, perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type.