ChecksummedData

Struct ChecksummedData 

pub struct ChecksummedData {
    pub crc32c_checksum: Option<i64>,
    pub data: Option<Vec<u8>>,
}
Data with integrity verification field.

This type is not used in any activity, and only used as part of another schema.

Fields

crc32c_checksum: Option<i64>

Integrity verification field. A CRC32C checksum of the returned ChecksummedData.data. An integrity check of ChecksummedData.data can be performed by computing the CRC32C checksum of ChecksummedData.data and comparing your results to this field. Discard the response in case of non-matching checksum values, and perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type.

data: Option<Vec<u8>>

Raw Data.