Struct google_cloudkms1::DestroyCryptoKeyVersionRequest [−][src]
pub struct DestroyCryptoKeyVersionRequest { /* fields omitted */ }Request message for KeyManagementService.DestroyCryptoKeyVersion.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).