Struct google_cloudkms1::EncryptRequest
source · pub struct EncryptRequest {
pub plaintext: Option<String>,
pub additional_authenticated_data: Option<String>,
}Expand description
Request message for KeyManagementService.Encrypt.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
plaintext: Option<String>Required. The data to encrypt. Must be no larger than 64KiB.
additional_authenticated_data: Option<String>Optional data that, if specified, must also be provided during decryption through DecryptRequest.additional_authenticated_data. Must be no larger than 64KiB.