pub struct ListCryptoKeyVersionsResponse {
pub next_page_token: Option<String>,
pub total_size: Option<i32>,
pub crypto_key_versions: Option<Vec<CryptoKeyVersion>>,
}Expand description
Response message for KeyManagementService.ListCryptoKeyVersions.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
next_page_token: Option<String>A token to retrieve next page of results. Pass this value in ListCryptoKeyVersionsRequest.page_token to retrieve the next page of results.
total_size: Option<i32>The total number of CryptoKeyVersions that matched the query.
crypto_key_versions: Option<Vec<CryptoKeyVersion>>The list of CryptoKeyVersions.