[][src]Struct google_cloudkms1::PublicKey

pub struct PublicKey {
    pub pem: Option<String>,
    pub algorithm: Option<String>,
}

The public key for a given CryptoKeyVersion. Obtained via GetPublicKey.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

pem: Option<String>

The public key, encoded in PEM format. For more information, see the RFC 7468 sections for General Considerations and [Textual Encoding of Subject Public Key Info] (https://tools.ietf.org/html/rfc7468#section-13).

algorithm: Option<String>

The Algorithm associated with this key.