Struct google_cloudkms1::AsymmetricSignResponse [−][src]
Response message for KeyManagementService.AsymmetricSign.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
signature: Option<String>
The created signature.